@@ -1,31 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2017 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the Qt Network Auth module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:GPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 or (at your option) any later version
-** approved by the KDE Free Qt Foundation. The licenses are as published by
-** the Free Software Foundation and appearing in the file LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2017 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
 #ifndef WEBSERVER_H
 #define WEBSERVER_H
@@ -33,6 +7,7 @@
 #include <functional>
 #include <cctype>
 #include <QtCore/qcoreapplication.h>
+#include <QtCore/qurl.h>
 #include <QtNetwork/qtcpserver.h>
 #include <QTcpSocket>
 
@@ -41,6 +16,7 @@ class WebServer : public QTcpServer
 public:
     class HttpRequest {
         friend class WebServer;
+        friend class TlsWebServer;
 
         quint16 port = 0;
         enum class State {
@@ -87,14 +63,14 @@ private:
     QMap<QTcpSocket *, HttpRequest> clients;
 };
 
-WebServer::WebServer(Handler handler, QObject *parent) :
+WebServer::WebServer(Handler h, QObject *parent) :
     QTcpServer(parent),
-    handler(handler)
+    handler(h)
 {
-    connect(this, &QTcpServer::newConnection, [=]() {
+    connect(this, &QTcpServer::newConnection, this, [this]() {
         auto socket = nextPendingConnection();
         connect(socket, &QTcpSocket::disconnected, socket, &QTcpSocket::deleteLater);
-        connect(socket, &QTcpSocket::readyRead, [=]() {
+        connect(socket, &QTcpSocket::readyRead, this, [this, socket]() {
             if (!clients.contains(socket))
                 clients[socket].port = serverPort();
 
